<?xml version='1.0'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version='1.0'>
<!--########################################################################### 
 |    $Id: book.mod.xsl,v 1.4 2001/03/31 13:00:54 ben Exp $
 |- ###########################################################################
 |   $Author: ben $
 |
 |   This file comes from the DB2LaTeX XSLT Stylesheets by Ramon Casellas who
 |   accepted its reuse and customization for this package.
 |                                                        
 |   PURPOSE:
 |    This template matches a book. For articles see article.mod.xsl
 |    Dumps the preamble as given in vars.mod.xsl, gets the title and author
 |    from the bookinfo child, dumps any information that may be applied after 
 |    the author and applies templates. Finally, the end{doc} is added.
 |    Since title/author are processed here, the only template we process 
 |    in bookinfo is the revision history.
 + ############################################################################ -->
 
<xsl:template match="book">
<xsl:value-of select="$lyx.book.preamblestart"/>
<xsl:call-template name="generate.lyx.common.preamble">
  <xsl:with-param name="textclass">docbook-book</xsl:with-param>
</xsl:call-template>
<xsl:choose>
  <xsl:when test="./title">
    <xsl:text>\layout Title&#10;</xsl:text>
    <xsl:value-of select="normalize-space(./title)"/>
  </xsl:when>
  <xsl:otherwise>
    <xsl:if test="./bookinfo/title">
      <xsl:apply-templates select="./bookinfo/title"/>
    </xsl:if>
  </xsl:otherwise>
</xsl:choose>
<xsl:text>&#10;</xsl:text>
<xsl:choose>
  <xsl:when test="bookinfo/authorgroup">
    <xsl:apply-templates select="bookinfo/authorgroup"/>
  </xsl:when>
  <xsl:otherwise>
    <xsl:apply-templates select="bookinfo/author"/>
  </xsl:otherwise>
</xsl:choose>
<xsl:call-template name="label.id"/>
<!-- APPLY TEMPLATES -->
<xsl:apply-templates/>
<xsl:value-of select="$lyx.book.end"/>
</xsl:template>


<xsl:template match="book/bookinfo/author|artheader/author|authorgroup/author">
<xsl:text>\layout Author&#10;</xsl:text>
<xsl:apply-templates/>
</xsl:template>

<xsl:template match="author/surname|author/firstname">
<xsl:call-template name="unsupported.inline"/>
</xsl:template>

<xsl:template match="book/bookinfo/date">
<xsl:text>\layout Date&#10;</xsl:text>
<xsl:value-of select="normalize-space(.)"/>
<xsl:text>&#10;</xsl:text>
</xsl:template>

<xsl:template match="book/bookinfo/title|artheader/title">
<xsl:text>\layout Title&#10;</xsl:text>
<xsl:value-of select="normalize-space(.)"/>
</xsl:template>



<xsl:template match="book/title"></xsl:template>
<xsl:template match="book/subtitle"></xsl:template>
<xsl:template match="book/bookinfo">
    <xsl:apply-templates select="revhistory" />
    <xsl:apply-templates select="date" />
    <xsl:apply-templates select="abstract" />
</xsl:template>

</xsl:stylesheet>

