<?xml version='1.0'?>
<!--########################################################################### 
 |    $Id: unsupported.mod.xsl,v 1.3 2001/04/25 21:19:44 ben Exp $        
 |- ###########################################################################
 |   $Author: ben $
 |
 |   PURPOSE: Generic procedure to translate elements that are not directly
 |            supported by LyX.
 |
 + ############################################################################ -->
<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:doc="http://nwalsh.com/xsl/documentation/1.0"
    exclude-result-prefixes="doc" version='1.0'>


<!-- Basically, undefined elements are directly printed as is. The element
     begin and end dislay the element tags. -->

<xsl:template match="@*" mode="attr.copy">
    <xsl:text> </xsl:text>
    <xsl:value-of select="name()"/>
    <xsl:text>="</xsl:text>
    <xsl:value-of select="."/>
    <xsl:text>"</xsl:text>
</xsl:template>

<xsl:template name="element.begin">
  <xsl:text>&lt;</xsl:text>
  <xsl:value-of select="name()"/>
  <xsl:apply-templates select="@*" mode="attr.copy"/>
  <xsl:text>&gt;</xsl:text>
</xsl:template>

<xsl:template name="element.end">
  <xsl:text>&lt;/</xsl:text>
  <xsl:value-of select="name()"/>
  <xsl:text>&gt;</xsl:text>
</xsl:template>


<!-- Method to include undefined inlined elements, with ERT.
     Note that the \latex commands should be terminated by a \n. Unfortunately
     if we do so the ragged.left funcion removes some expected spaces.
-->

<xsl:template name="unsupported.inline">
  <xsl:message>***Warning: element &lt;<xsl:value-of select="name()"/>&gt; not translated</xsl:message>
  <xsl:param name="content">
    <xsl:apply-templates/>
  </xsl:param>
  <xsl:text>&#10;\latex latex </xsl:text>
  <xsl:call-template name="element.begin"/>
  <xsl:text>&#10;\latex default </xsl:text>
  
  <xsl:copy-of select="$content"/>
  
  <xsl:text>&#10;\latex latex </xsl:text>
  <xsl:call-template name="element.end"/>
  <xsl:text>&#10;\latex default </xsl:text>
</xsl:template>


<!-- Method to include undefined blocks elements, with SGML layout. -->

<xsl:template name="unsupported.block">
  <xsl:message>***Warning: element &lt;<xsl:value-of select="name()"/>&gt; not translated</xsl:message>
  <xsl:text>&#10;\layout SGML&#10;</xsl:text>
  <xsl:call-template name="element.begin"/>
  <xsl:text>&#10;</xsl:text>

  <xsl:apply-templates/>

  <xsl:text>&#10;\layout SGML&#10;</xsl:text>
  <xsl:call-template name="element.end"/>
  <xsl:text>&#10;</xsl:text>
</xsl:template>

</xsl:stylesheet>
